@@ -1,4 +1,4 @@
-architect<-function(inputrac=NULL, inputtps=NULL, inputrsml=NULL, res=NULL, unitlength="px", rsml.date=NULL, rsml.connect=FALSE, rootdiv=1){
+architect<-function(inputrac=NULL, inputtps=NULL, inputrsml=NULL, res=NULL, unitlength="px", rsml.date=NULL, rsml.connect=FALSE){
   
   # Errors interception
   
@@ -13,7 +13,7 @@ architect<-function(inputrac=NULL, inputtps=NULL, inputrsml=NULL, res=NULL, unit
   
   if (is.null(inputrsml)==FALSE) {if (mode(inputrsml)!="character"){stop("mode(inputrsml) must be character")}}
   
-  if (is.null(res)==TRUE & unitlength!="px"){stop("If unitlength is not px, res must be specified")}
+  if (is.null(inputrac)==FALSE & is.null(res)==TRUE & unitlength!="px"){stop("If unitlength is not px, res must be specified")}
   if (is.null(res)==FALSE){
     if (mode(res)!="numeric"){stop("mode(res) must be numeric")}
     if (res<=0|length(res)>1){stop("res must be a single positive value")}}
@@ -21,18 +21,12 @@ architect<-function(inputrac=NULL, inputtps=NULL, inputrsml=NULL, res=NULL, unit
   if (mode(unitlength)!="character"){stop("mode(unitlength) must be character")}
   if (unitlength=="px"|unitlength=="mm"|unitlength=="cm") {} else {stop("unitlength must be either px (pixels), mm (millimeters) or cm (centimeters)")}
   
-  if (is.null(inputrsml)==FALSE & is.null(rsml.date)==TRUE) {stop("If inputrsml is not NULL, rsml.date must be a positive numeric value")}
-  
   if (is.null(rsml.date)==FALSE){
-    if (rsml.date<=0|length(rsml.date)>1){stop("rsml.date must be a single positive value")}}
+    if (is.character(rsml.date)==TRUE|is.numeric(rsml.date)==TRUE){} else {stop("If rsml.date is not NULL, rsml.date must be a character string or a positive numeric value")}
+    if (is.numeric(rsml.date)==TRUE){if (rsml.date<=0|length(rsml.date)>1){stop("If mode(rsml.date) is numeric, rsml.date must be a single positive value")}}}
   
   if (mode(rsml.connect)!="logical"){stop("mode(rsml.connect) must be logical")}
   
-  if (mode(rootdiv)!="numeric"){stop("mode(rootdiv) must be numeric")}
-  for (i in 1:length(rootdiv)){if (rootdiv[i]<0){stop("rootdiv must be either a positive value or a vector of positive values")}}
-  rootdiv.sort<-sort(rootdiv)
-  for (i in 1:length(rootdiv)) {if (rootdiv[i]!=rootdiv.sort[i]){stop("Numeric elements in rootdiv must be sorted by increasing values")}}
-  
   # Reading of DART and rsml files
   
   if (is.null(inputtps)==FALSE){
@@ -84,6 +78,7 @@ architect<-function(inputrac=NULL, inputtps=NULL, inputrsml=NULL, res=NULL, unit
           age[[i]]<-TIME[[1]]$Date
           obstot<-obstot+length(age[[i]])}
         for (i in 1:length(DATA)) {if(length(age[[i]])!=(ncol(DATA[[i]])-5)){stop("The number of observation dates between corresponding rac et tps files must be equal")}}}
+      
       else {
         if (length(TIME)!=length(DATA)) {stop("If there is more than one tps file in inputtps, the number of rac files in inputrac and tps files in inputtps must be equal")}
         else {
@@ -100,15 +95,20 @@ architect<-function(inputrac=NULL, inputtps=NULL, inputrsml=NULL, res=NULL, unit
       
       DATA<-list()
       age<-list()
+      res1<-c()
       filenamesrac<-c()
       RSML <- lapply(paste(path.rsml, "/", filenames.rsml, sep=""), rsmlToDART, final.date=rsml.date, connect=rsml.connect) # Read RSML files
       obstot<-0
       for (i in 1:length(RSML)){
-        for (j in 1:length(RSML[[i]]$rac)){colnames(RSML[[i]]$rac[[j]])[6]<-"Lengths1"}
+        res1<-append(res1, rep(as.numeric(RSML[[i]]$resolution), length(RSML[[i]]$lie)))
         DATA<-append(DATA, RSML[[i]]$rac)
         length1<-length(RSML[[i]]$rac)
-        obstot<-obstot+length1
-        age[(length(age)+1):(length(age)+length1)]<-rsml.date
+        
+        l<-length(age)
+        for (j in 1:length1) {
+          age[[l+j]]<-RSML[[i]]$tps[[j]]$Date
+          obstot<-obstot+length(age[[l+j]])}
+
         if (length1>1){
           num<-c(1:length1)
           filenamesrac[(length(filenamesrac)+1):(length(filenamesrac)+length1)]<-paste(rep(filenamesrsml[i], length.out=length1), num, sep="")}
@@ -129,6 +129,8 @@ architect<-function(inputrac=NULL, inputtps=NULL, inputrsml=NULL, res=NULL, unit
         colnames(DATA[[i]])[5]<-"DApp"
         for (j in 6:ncol(DATA[[i]])-5) {colnames(DATA[[i]])[j+5]<-paste("Lengths", j, sep="")}}
       
+      res1<-rep(res, length(filenames.rac))
+      
       if (length(TIME)==1) {
         age<-list()
         obstot<-0
@@ -150,11 +152,15 @@ architect<-function(inputrac=NULL, inputtps=NULL, inputrsml=NULL, res=NULL, unit
       RSML <- lapply(paste(path.rsml, "/", filenames.rsml, sep=""), rsmlToDART, final.date=rsml.date, connect=rsml.connect) # Read RSML files
       
       for (i in 1:length(RSML)){
-        for (j in 1:length(RSML[[i]]$rac)){colnames(RSML[[i]]$rac[[j]])[6]<-"Lengths1"}
+        res1<-append(res1, rep(as.numeric(RSML[[i]]$resolution), length(RSML[[i]]$lie)))
         DATA<-append(DATA, RSML[[i]]$rac)
         length1<-length(RSML[[i]]$rac)
-        obstot<-obstot+length1
-        age[(length(age)+1):(length(age)+length1)]<-rsml.date
+        
+        l<-length(age)
+        for (j in 1:length1) {
+          age[[l+j]]<-RSML[[i]]$tps[[j]]$Date
+          obstot<-obstot+length(age[[l+j]])}
+        
         if (length1>1){
           num<-c(1:length1)
           filenamesrac[(length(filenamesrac)+1):(length(filenamesrac)+length1)]<-paste(rep(filenamesrsml[i], length.out=length1), num, sep="")}
@@ -166,6 +172,7 @@ architect<-function(inputrac=NULL, inputtps=NULL, inputrsml=NULL, res=NULL, unit
   FileNames<-c()
   Time<-c()
   FirstOrderRootLength<-c()
+  FirstOrderRootNumber<-c()
   TotalRootLength<-c()
   TotalLateralRootNumber<-c()
   TotalLateralRootLength<-c()
@@ -173,19 +180,6 @@ architect<-function(inputrac=NULL, inputtps=NULL, inputrsml=NULL, res=NULL, unit
   GrowthRateFirstOrderRoot<-c()
   GrowthRateTotalRoot<-c()
   
-  if ((length(rootdiv)==1 & rootdiv[1]!=1)|(length(rootdiv)>1)) {
-    ColLengthsNumber<-0
-    for (i in 1:length(DATA)) {ColLengthsNumber<-ColLengthsNumber+(ncol(DATA[[i]])-5)}
-    
-    if (length(rootdiv)==1){
-      LRNDroot<-matrix(nrow=ColLengthsNumber,ncol=rootdiv)
-      LRLDroot<-matrix(nrow=ColLengthsNumber,ncol=rootdiv)
-      LRDDroot<-matrix(nrow=ColLengthsNumber,ncol=rootdiv)}
-    else {
-      LRNDroot<-matrix(nrow=ColLengthsNumber,ncol=length(rootdiv)-1)
-      LRLDroot<-matrix(nrow=ColLengthsNumber,ncol=length(rootdiv)-1)
-      LRDDroot<-matrix(nrow=ColLengthsNumber,ncol=length(rootdiv)-1)}}		
-  
   # Calculation of root architecture parameters
   
   k<-0
@@ -200,17 +194,20 @@ architect<-function(inputrac=NULL, inputtps=NULL, inputrsml=NULL, res=NULL, unit
       
       k<-k+1
       
+      # Time
+      Time[k]<-age[[i]][t]
+      
+      #Split data per root order
       data.split<-split(DATA[[i]][[paste("Lengths",t,sep="")]],as.factor(DATA[[i]]$Ord))
       
       # File names
       
       FileNames[k]<-filenamesrac[i]
       
-      # Time
-      Time[k]<-age[[i]][t]
-      
       # Unit conversion
       
+      if (is.null(inputrsml)==FALSE){res<-res1[i]}
+      
       if (unitlength=="mm") {cunit<-(10*cm(1)/res)}
       if (unitlength=="cm") {cunit<-(cm(1)/res)}
       if (unitlength=="px") {cunit<-1}	
@@ -233,9 +230,13 @@ architect<-function(inputrac=NULL, inputtps=NULL, inputrsml=NULL, res=NULL, unit
       if (t==1) {GrowthRateFirstOrderRoot[k]<-FirstOrderRootLength[k]/age[[i]][t]}
       if (t>1) {GrowthRateFirstOrderRoot[k]<-(FirstOrderRootLength[k]-FirstOrderRootLength[k-1])/(age[[i]][t]-age[[i]][t-1])}
       
+      # Total number of first-order roots
+      
+      FirstOrderRootNumber[k]<-sum(data.split$'1'!=0)
+      
       # Total number of lateral roots
       
-      if (FirstOrderRootLength[k]==0) {TotalLateralRootNumber[k]<-0}  else {TotalLateralRootNumber[k]<-sum(DATA[[i]][[paste("Lengths",t,sep="")]]!=0)-length(data.split$'1')}
+      if (FirstOrderRootLength[k]==0) {TotalLateralRootNumber[k]<-0}  else {TotalLateralRootNumber[k]<-sum(DATA[[i]][[paste("Lengths",t,sep="")]]!=0)-FirstOrderRootNumber[k]}
       
       # Total length of lateral roots
       
@@ -253,38 +254,13 @@ architect<-function(inputrac=NULL, inputtps=NULL, inputrsml=NULL, res=NULL, unit
       
       # Density of secondary roots on the first-order root
       
-      if (FirstOrderRootLength[k]==0|maxord==1) {LateralRootDensity[k]<-0} else {LateralRootDensity[k]<-latroot[k,1]/FirstOrderRootLength[k]} 
-      
-      # Rootdiv
-      
-      if ((length(rootdiv)==1 & rootdiv[1]!=1)|(length(rootdiv)>1)) {
-        
-        Ord=NULL
-        DBase=NULL
-        
-        # Secondary root number, length and density distribution on the first-order root
-        
-        if (length(rootdiv)==1){
-          rootdiv1<-(0:rootdiv)*LastFirstOrderRootLength*cunit/rootdiv}
-        else {rootdiv1<-rootdiv}
-        
-        for (j in 1:(length(rootdiv1)-1)){
-          
-         sub<-subset(DATA[[i]], (DBase!=0) & (DBase >= rootdiv1[j]/cunit) & (DBase < rootdiv1[j+1]/cunit) & (Ord==2))
-         LRNDroot[k,j]<-sum(sub[[paste("Lengths",t,sep="")]]!=0)
-         LRLDroot[k,j]<-sum(sub[[paste("Lengths",t,sep="")]])*cunit
-         LRDDroot[k,j]<-LRNDroot[k,j]/(rootdiv1[j+1]-rootdiv1[j])}}}}	
+      if (FirstOrderRootLength[k]==0|maxord==1) {LateralRootDensity[k]<-0} else {LateralRootDensity[k]<-latroot[k,1]/FirstOrderRootLength[k]}}}	
   
   # Summarying results in a data frame
   
-  if ((length(rootdiv)==1 & rootdiv[1]!=1)|(length(rootdiv)>1)) {
-    
-    if (maxord>1) {outputresults<-data.frame(FileNames, Time, TotalRootLength, GrowthRateTotalRoot, FirstOrderRootLength, GrowthRateFirstOrderRoot, TotalLateralRootNumber, TotalLateralRootLength, latroot, LateralRootDensity, LRNDroot, LRLDroot, LRDDroot)}
-    else {outputresults<-data.frame(FileNames, Time, TotalRootLength, GrowthRateTotalRoot, FirstOrderRootLength, GrowthRateFirstOrderRoot, TotalLateralRootNumber, TotalLateralRootLength, LateralRootDensity, LRNDroot, LRLDroot, LRDDroot)}}
-  
-  else {
-    if (maxord>1) {outputresults<-data.frame(FileNames, Time, TotalRootLength, GrowthRateTotalRoot, FirstOrderRootLength, GrowthRateFirstOrderRoot, TotalLateralRootNumber, TotalLateralRootLength, latroot, LateralRootDensity)}
-    else {outputresults<-data.frame(FileNames, Time, TotalRootLength, GrowthRateTotalRoot, FirstOrderRootLength, GrowthRateFirstOrderRoot, TotalLateralRootNumber, TotalLateralRootLength, LateralRootDensity)}}
+
+  if (maxord>1) {outputresults<-data.frame(FileNames, Time, TotalRootLength, GrowthRateTotalRoot, FirstOrderRootLength, GrowthRateFirstOrderRoot, FirstOrderRootNumber, TotalLateralRootNumber, TotalLateralRootLength, latroot, LateralRootDensity)}
+  else {outputresults<-data.frame(FileNames, Time, TotalRootLength, GrowthRateTotalRoot, FirstOrderRootLength, GrowthRateFirstOrderRoot, FirstOrderRootNumber, TotalLateralRootNumber, TotalLateralRootLength, LateralRootDensity)}
   
   if (maxord>1){
   LRnumberheading<-c()
@@ -298,39 +274,7 @@ architect<-function(inputrac=NULL, inputtps=NULL, inputrsml=NULL, res=NULL, unit
     LRmeanlengthheading[h-1]<-paste("ML", h, "LR", sep="")
     LRgrowthrateheading[h-1]<-paste("GR", h, "L", sep="")}}
   
-  if ((length(rootdiv)==1 & rootdiv[1]!=1)|(length(rootdiv)>1)) {
-    
-    LRNDheading<-c()
-    if (length(rootdiv)==1){
-      for (h in 1:rootdiv)
-      {LRNDheading[h]<-paste("N2LR.Layer", h, sep="")}}
-    else {
-      for (h in 2:length(rootdiv)-1)
-      {LRNDheading[h]<-paste("N2LR.", rootdiv[h], "to", rootdiv[h+1], sep="")}}
-    
-    LRLDheading<-c()
-    if (length(rootdiv)==1){
-      for (h in 1:rootdiv)
-      {LRLDheading[h]<-paste("L2LR.Layer", h, sep="")}}
-    else {
-      for (h in 2:length(rootdiv)-1)
-      {LRLDheading[h]<-paste("L2LR.", rootdiv[h], "to", rootdiv[h+1], sep="")}}
-    
-    LRDDheading<-c()
-    if (length(rootdiv)==1){
-      for (h in 1:rootdiv)
-      {LRDDheading[h]<-paste("D2LR.Layer", h, sep="")}}
-    else {
-      for (h in 2:length(rootdiv)-1)
-      {LRDDheading[h]<-paste("D2LR.", rootdiv[h], "to", rootdiv[h+1], sep="")}}}
-  
-  if ((length(rootdiv)==1 & rootdiv[1]!=1)|(length(rootdiv)>1)) {
-    
-    if (maxord>1) {colnames(outputresults)<-c("FileName", "Time", "TRL", "GRTR", "L1R", "GR1R", "TNLR", "TLRL", t(LRnumberheading), t(LRlengthheading), t(LRmeanlengthheading), t(LRgrowthrateheading), "D2LR", t(LRNDheading), t(LRLDheading), t(LRDDheading))}
-    else {colnames(outputresults)<-c("FileName", "Time", "TRL", "GRTR", "L1R", "GR1R", "TNLR", "TLRL", "D2LR", t(LRNDheading), t(LRLDheading), t(LRDDheading))}}
-  
-  else {
-    if (maxord>1) {colnames(outputresults)<-c("FileName", "Time", "TRL", "GRTR", "L1R", "GR1R", "TNLR", "TLRL", t(LRnumberheading), t(LRlengthheading), t(LRmeanlengthheading), t(LRgrowthrateheading), "D2LR")}
-    else {colnames(outputresults)<-c("FileName", "Time", "TRL", "GRTR", "L1R", "GR1R", "TNLR", "TLRL", "D2LR")}}
+  if (maxord>1) {colnames(outputresults)<-c("FileName", "Time", "TRL", "GRTR", "L1R", "GR1R", "TN1R", "TNLR", "TLRL", t(LRnumberheading), t(LRlengthheading), t(LRmeanlengthheading), t(LRgrowthrateheading), "D2LR")}
+  else {colnames(outputresults)<-c("FileName", "Time", "TRL", "GRTR", "L1R", "GR1R", "TN1R", "TNLR", "TLRL", "D2LR")}
   
   return(outputresults)}
\ No newline at end of file
